@@ -6,11 +6,11 @@ class Elastic(object):
     """
     A thin wrapper around elasticsearch.Elasticsearch()
     """
-    def __init__(self, app=None):
+    def __init__(self, app=None, **kwargs):
         if app is not None:
-            self.init_app(app)
+            self.init_app(app, **kwargs)
 
-    def init_app(self, app):
+    def init_app(self, app, **kwargs):
         app.config.setdefault('ELASTICSEARCH_URL', 'http://localhost:9200/')
 
         # using the app factory pattern _app_ctx_stack.top is None so what
@@ -18,7 +18,7 @@ class Elastic(object):
         # know flask well enough to be sure), but that's how it's done in
         # flask-pymongo so let's use it for now.
         app.extensions['elastic'] = \
-            Elasticsearch(app.config['ELASTICSEARCH_URL'])
+            Elasticsearch(app.config['ELASTICSEARCH_URL'], **kwargs)
 
     def __getattr__(self, item):
         if not 'elastic' in current_app.extensions.keys():
